@@ -19,7 +19,7 @@ subroutine force()
 
   implicit none
 
-  integer :: i, j, k
+  integer :: i, j
 
   !-- ν
   call complex_init( forceu )
@@ -158,12 +158,9 @@ subroutine force()
      call complex_init( frdupdt )
      call complex_init( frdvpdt )
      call complex_init( frdhpdt )
-     call complex_init( fupup )
      call complex_init( fupvp )
      call complex_init( fuphp )
      call complex_init( fvpvp )
-     call complex_init( fvphp )
-     call complex_init( fhphp )
      call complex_init( fupdup )
      call complex_init( fupdvp )
      call complex_init( fupdhp )
@@ -173,12 +170,9 @@ subroutine force()
      call complex_init( fhpdup )
      call complex_init( fhpdvp )
      call complex_init( fhpdhp )
-     call complex_init( fiupup )
      call complex_init( fiupvp )
      call complex_init( fiuphp )
      call complex_init( fivpvp )
-     call complex_init( fivphp )
-     call complex_init( fihphp )
      call complex_init( fiupdup )
      call complex_init( fiupdvp )
      call complex_init( fiupdhp )
@@ -187,7 +181,6 @@ subroutine force()
      call complex_init( fivpdhp )
      call complex_init( fihpdup )
      call complex_init( fihpdvp )
-     call complex_init( fihpdhp )
 
      !-- ڥȥѿѴˡѤγĥ֤
      do i=2,nr-1  ! j=1 ̽
@@ -230,16 +223,34 @@ subroutine force()
 !$omp parallel default(shared)
 !$omp do private(i)
      do i=2,nr-1
-        call ffttp_1d( jnt, fup(i,:), frup(i,:), 'i', prim='o' )
-        call ffttp_1d( jnt, fvp(i,:), frvp(i,:), 'i', prim='o' )
-        call ffttp_1d( jnt, fhp(i,:), frhp(i,:), 'i', prim='o' )
+        call ffttp_1d( jnt, fup(i,:), frup(i,:), 'i', prim='o',  &
+  &                    prim_fact=pfact,  &
+  &                    omega_fix=omega_bi(0:pfact(5)-1,0:pfact(5)-1),  &
+  &                    omegan_fix=omega_ni(0:jnt-1,0:jnt-1) )
+        call ffttp_1d( jnt, fvp(i,:), frvp(i,:), 'i', prim='o',  &
+  &                    prim_fact=pfact,  &
+  &                    omega_fix=omega_bi(0:pfact(5)-1,0:pfact(5)-1),  &
+  &                    omegan_fix=omega_ni(0:jnt-1,0:jnt-1) )
+        call ffttp_1d( jnt, fhp(i,:), frhp(i,:), 'i', prim='o',  &
+  &                    prim_fact=pfact,  &
+  &                    omega_fix=omega_bi(0:pfact(5)-1,0:pfact(5)-1),  &
+  &                    omegan_fix=omega_ni(0:jnt-1,0:jnt-1) )
 ! ʲ,  fr?p ưʬȤ뤳Ȥ FFT 򤹤.
 !        call ffttp_1d( jnt, fdupdr(i,:), frdupdr(i,:), 'i', prim='o' )
 !        call ffttp_1d( jnt, fdvpdr(i,:), frdvpdr(i,:), 'i', prim='o' )
 !        call ffttp_1d( jnt, fdhpdr(i,:), frdhpdr(i,:), 'i', prim='o' )
-        call ffttp_1d( jnt, fdupdt(i,:), frdupdt(i,:), 'i', prim='o' )
-        call ffttp_1d( jnt, fdvpdt(i,:), frdvpdt(i,:), 'i', prim='o' )
-        call ffttp_1d( jnt, fdhpdt(i,:), frdhpdt(i,:), 'i', prim='o' )
+        call ffttp_1d( jnt, fdupdt(i,:), frdupdt(i,:), 'i', prim='o',  &
+  &                    prim_fact=pfact,  &
+  &                    omega_fix=omega_bi(0:pfact(5)-1,0:pfact(5)-1),  &
+  &                    omegan_fix=omega_ni(0:jnt-1,0:jnt-1) )
+        call ffttp_1d( jnt, fdvpdt(i,:), frdvpdt(i,:), 'i', prim='o',  &
+  &                    prim_fact=pfact,  &
+  &                    omega_fix=omega_bi(0:pfact(5)-1,0:pfact(5)-1),  &
+  &                    omegan_fix=omega_ni(0:jnt-1,0:jnt-1) )
+        call ffttp_1d( jnt, fdhpdt(i,:), frdhpdt(i,:), 'i', prim='o',  &
+  &                    prim_fact=pfact,  &
+  &                    omega_fix=omega_bi(0:pfact(5)-1,0:pfact(5)-1),  &
+  &                    omegan_fix=omega_ni(0:jnt-1,0:jnt-1) )
      end do
 !$omp end do
 !$omp end parallel
@@ -265,12 +276,9 @@ subroutine force()
            fhpdup(i,j)=frhp(i,j)*frdupdr(i,j)
            fhpdvp(i,j)=frhp(i,j)*frdvpdt(i,j)  ! ι theta ʬʤ
 !           fhpdhp(i,j)=frhp(i,j)*frdhpdr(i,j)
-!           fupup(i,j)=frup(i,j)*frup(i,j)
            fupvp(i,j)=frup(i,j)*frvp(i,j)
            fuphp(i,j)=frup(i,j)*frhp(i,j)
            fvpvp(i,j)=frvp(i,j)*frvp(i,j)
-!           fvphp(i,j)=frvp(i,j)*frhp(i,j)
-!           fhphp(i,j)=frhp(i,j)*frhp(i,j)
         end do
      end do
 !$omp end do
@@ -281,21 +289,50 @@ subroutine force()
 !$omp parallel default(shared)
 !$omp do private(i)
      do i=2,nr-1
-        call ffttp_1d( jnt, fupdup(i,:), fiupdup(i,:), 'r', prim='o' )
-        call ffttp_1d( jnt, fupdvp(i,:), fiupdvp(i,:), 'r', prim='o' )
-        call ffttp_1d( jnt, fupdhp(i,:), fiupdhp(i,:), 'r', prim='o' )
-        call ffttp_1d( jnt, fvpdup(i,:), fivpdup(i,:), 'r', prim='o' )
-        call ffttp_1d( jnt, fvpdvp(i,:), fivpdvp(i,:), 'r', prim='o' )
-        call ffttp_1d( jnt, fvpdhp(i,:), fivpdhp(i,:), 'r', prim='o' )
-        call ffttp_1d( jnt, fhpdup(i,:), fihpdup(i,:), 'r', prim='o' )
-        call ffttp_1d( jnt, fhpdvp(i,:), fihpdvp(i,:), 'r', prim='o' )
-!        call ffttp_1d( jnt, fhpdhp(i,:), fihpdhp(i,:), 'r', prim='o' )
-!        call ffttp_1d( jnt, fupup(i,:), fiupup(i,:), 'r', prim='o' )
-        call ffttp_1d( jnt, fupvp(i,:), fiupvp(i,:), 'r', prim='o' )
-        call ffttp_1d( jnt, fuphp(i,:), fiuphp(i,:), 'r', prim='o' )
-        call ffttp_1d( jnt, fvpvp(i,:), fivpvp(i,:), 'r', prim='o' )
-!        call ffttp_1d( jnt, fvphp(i,:), fivphp(i,:), 'r', prim='o' )
-!        call ffttp_1d( jnt, fhphp(i,:), fihphp(i,:), 'r', prim='o' )
+        call ffttp_1d( jnt, fupdup(i,:), fiupdup(i,:), 'r', prim='o',  &
+  &                    prim_fact=pfact,  &
+  &                    omega_fix=omega_br(0:pfact(5)-1,0:pfact(5)-1),  &
+  &                    omegan_fix=omega_nr(0:jnt-1,0:jnt-1) )
+        call ffttp_1d( jnt, fupdvp(i,:), fiupdvp(i,:), 'r', prim='o',  &
+  &                    prim_fact=pfact,  &
+  &                    omega_fix=omega_br(0:pfact(5)-1,0:pfact(5)-1),  &
+  &                    omegan_fix=omega_nr(0:jnt-1,0:jnt-1) )
+        call ffttp_1d( jnt, fupdhp(i,:), fiupdhp(i,:), 'r', prim='o',  &
+  &                    prim_fact=pfact,  &
+  &                    omega_fix=omega_br(0:pfact(5)-1,0:pfact(5)-1),  &
+  &                    omegan_fix=omega_nr(0:jnt-1,0:jnt-1) )
+        call ffttp_1d( jnt, fvpdup(i,:), fivpdup(i,:), 'r', prim='o',  &
+  &                    prim_fact=pfact,  &
+  &                    omega_fix=omega_br(0:pfact(5)-1,0:pfact(5)-1),  &
+  &                    omegan_fix=omega_nr(0:jnt-1,0:jnt-1) )
+        call ffttp_1d( jnt, fvpdvp(i,:), fivpdvp(i,:), 'r', prim='o',  &
+  &                    prim_fact=pfact,  &
+  &                    omega_fix=omega_br(0:pfact(5)-1,0:pfact(5)-1),  &
+  &                    omegan_fix=omega_nr(0:jnt-1,0:jnt-1) )
+        call ffttp_1d( jnt, fvpdhp(i,:), fivpdhp(i,:), 'r', prim='o',  &
+  &                    prim_fact=pfact,  &
+  &                    omega_fix=omega_br(0:pfact(5)-1,0:pfact(5)-1),  &
+  &                    omegan_fix=omega_nr(0:jnt-1,0:jnt-1) )
+        call ffttp_1d( jnt, fhpdup(i,:), fihpdup(i,:), 'r', prim='o',  &
+  &                    prim_fact=pfact,  &
+  &                    omega_fix=omega_br(0:pfact(5)-1,0:pfact(5)-1),  &
+  &                    omegan_fix=omega_nr(0:jnt-1,0:jnt-1) )
+        call ffttp_1d( jnt, fhpdvp(i,:), fihpdvp(i,:), 'r', prim='o',  &
+  &                    prim_fact=pfact,  &
+  &                    omega_fix=omega_br(0:pfact(5)-1,0:pfact(5)-1),  &
+  &                    omegan_fix=omega_nr(0:jnt-1,0:jnt-1) )
+        call ffttp_1d( jnt, fupvp(i,:), fiupvp(i,:), 'r', prim='o',  &
+  &                    prim_fact=pfact,  &
+  &                    omega_fix=omega_br(0:pfact(5)-1,0:pfact(5)-1),  &
+  &                    omegan_fix=omega_nr(0:jnt-1,0:jnt-1) )
+        call ffttp_1d( jnt, fuphp(i,:), fiuphp(i,:), 'r', prim='o',  &
+  &                    prim_fact=pfact,  &
+  &                    omega_fix=omega_br(0:pfact(5)-1,0:pfact(5)-1),  &
+  &                    omegan_fix=omega_nr(0:jnt-1,0:jnt-1) )
+        call ffttp_1d( jnt, fvpvp(i,:), fivpvp(i,:), 'r', prim='o',  &
+  &                    prim_fact=pfact,  &
+  &                    omega_fix=omega_br(0:pfact(5)-1,0:pfact(5)-1),  &
+  &                    omegan_fix=omega_nr(0:jnt-1,0:jnt-1) )
      end do
 !$omp end do
 !$omp end parallel
@@ -312,13 +349,9 @@ subroutine force()
            vpdhp(i,j)=fivpdhp(i,j)
            hpdup(i,j)=fihpdup(i,j)
            hpdvp(i,j)=fihpdvp(i,j)
-!           hpdhp(i,j)=fihpdhp(i,j)
-!           upup(i,j)=fiupup(i,j)
            upvp(i,j)=fiupvp(i,j)
            uphp(i,j)=fiuphp(i,j)
            vpvp(i,j)=fivpvp(i,j)
-!           vphp(i,j)=fivphp(i,j)
-!           hphp(i,j)=fihphp(i,j)
         end do
      end do
 
