@@ -48,6 +48,7 @@ program draw
   call SGISET('IFONT',2 )
   call UZFACT( 0.6 )
   call GLLSET('LMISS',.TRUE.)
+  call DclSetParm( 'ENABLE_CONTOUR_MESSAGE', .false. )
 
   if(trim(title)=='')then
      draw_title=trim(cont_val)//' and '//trim(shade_val)
@@ -218,14 +219,16 @@ write(*,*) "draw", trim(draw_title)
         cmax=smax
      end if
 
-     call Dcl_PL( trim(line_flag), trim(draw_title),  &
-  &       xd(xdmin:xdmax,ydmin:ydmax),  &
-  &       val1(xdmin:xdmax,ydmin:ydmax),  &
-  &       xd(xdmin:xdmax,ydmin:ydmax),  &
-  &       val2(xdmin:xdmax,ydmin:ydmax),  &
-  &       (/trim(x_axis), '               '/),  &
-  &       x_int=(/xd(xdmin,1), xd(xdmax,1)/), y_int=(/cmin, cmax/),  &
-  &       viewx_int=(/0.2, 0.8/), viewy_int=(/0.2, 0.8/) )
+     do i=ydmin,ydmax
+        call Dcl_PL( trim(line_flag), trim(draw_title),  &
+  &          xd(xdmin:xdmax,i:i),  &
+  &          val1(xdmin:xdmax,i:i),  &
+  &          xd(xdmin:xdmax,i:i),  &
+  &          val2(xdmin:xdmax,i:i),  &
+  &          (/trim(x_axis), '               '/),  &
+  &          x_int=(/xd(xdmin,1), xd(xdmax,1)/), y_int=(/cmin, cmax/),  &
+  &          viewx_int=(/0.2, 0.8/), viewy_int=(/0.2, 0.8/) )
+     end do
   end if
 
   if(fig_type==-2)then  ! y axis line draw
@@ -251,14 +254,16 @@ write(*,*) "draw", trim(draw_title)
         cmax=smax
      end if
 
-     call Dcl_PL( trim(line_flag), trim(draw_title),  &
-  &       dum1(xdmin:xdmax,ydmin:ydmax),  &
-  &       yd(ydmin:ydmax,xdmin:xdmax),  &
-  &       dum2(xdmin:xdmax,ydmin:ydmax),  &
-  &       yd(ydmin:ydmax,xdmin:xdmax),  &
-  &       (/'               ', trim(y_axis)/),  &
-  &       x_int=(/yd(ydmin,1), yd(ydmax,1)/), y_int=(/cmin, cmax/),  &
-  &       viewx_int=(/0.2, 0.8/), viewy_int=(/0.2, 0.8/) )
+     do i=xdmin,xdmax
+        call Dcl_PL( trim(line_flag), trim(draw_title),  &
+  &          dum1(i:i,ydmin:ydmax),  &
+  &          yd(ydmin:ydmax,i:i),  &
+  &          dum2(i:i,ydmin:ydmax),  &
+  &          yd(ydmin:ydmax,i:i),  &
+  &          (/'               ', trim(y_axis)/),  &
+  &          x_int=(/yd(ydmin,1), yd(ydmax,1)/), y_int=(/cmin, cmax/),  &
+  &          viewx_int=(/0.2, 0.8/), viewy_int=(/0.2, 0.8/) )
+     end do
   end if
 
 
