@@ -7,15 +7,16 @@ program wind
   use gtool_history
   implicit none
   integer :: i, j
-  integer, parameter :: nx=300, ny=300  ! ʿʻ
-  integer, parameter :: tstep=20000     ! ήη׻ƥå
-  real, dimension(nx,ny) :: u, v  ! Ϲ
+  integer, parameter :: nx=300, ny=300    ! ʿʻ
+  integer, parameter :: tstep=20000       ! ήη׻ƥå
+  real, dimension(nx,ny) :: u, v          ! Ϲ
   real, dimension(nx,ny) :: rot_2d, pres  ! ľ٤ȵ
-  real, dimension(tstep,1) :: tx, ty  ! ή x, y ɸ
-  real :: x(nx), y(ny)  ! ֺɸ
-  real, parameter :: xmin=-pi, xmax=pi, ymin=-pi, ymax=pi  ! ֤ΰ
-  real, parameter :: dt=0.1  ! ήη׻ֳִ
-  real :: dx, dy  ! ʻҲ
+  real, dimension(tstep,1) :: tx, ty      ! ή x, y ɸ
+  real :: x(nx), y(ny)                    ! ֺɸ
+  real, parameter :: xmin=-pi, xmax=pi    ! x ΰ 
+  real, parameter :: ymin=-pi, ymax=pi    ! y ΰ
+  real, parameter :: dt=0.1               ! ήη׻ֳִ
+  real :: dx, dy                          ! ʻҲ
   character(3) :: sche
 
   dx=(xmax-xmin)/(nx-1)
@@ -45,13 +46,13 @@ program wind
 
   call curl( x, y, u, v, rot_2d )  ! u, v Ϲ٤׻
 
-  call Stream_Line_2d( dt,  &  ! ֳִ
-  &                    tstep,  &  ! ֥ƥå
-  &                    0.1, 0.1,  &  ! ѡν (x,y) ɸ
-  &                    x, y,  &  ! x, y ɸ
-  &                    u, v,  &  ! x, y γƤ®پ
+  call Stream_Line_2d( dt,  &                ! ֳִ
+  &                    tstep,  &             ! ֥ƥå
+  &                    0.1, 0.1,  &          ! ѡν (x,y) ɸ
+  &                    x, y,  &              ! x, y ɸ
+  &                    u, v,  &              ! x, y γƤ®پ
   &                    tx(:,1), ty(:,1),  &  ! ºݤήε
-  &                    sche )  ! ֥
+  &                    sche )                ! ֥
 
 !-- gtool writing (netcdf)
 
