@@ -9,6 +9,43 @@ interface Bubble_Sort
 
 end interface Bubble_Sort
 
+interface LSM
+
+  module procedure LSM_1d
+
+end interface
+
+interface LSM_poly
+
+  module procedure LSM_poly_1d
+
+end interface
+
+interface covariance
+
+  module procedure covariance_1d
+
+end interface
+
+interface Cor_Coe
+
+  module procedure Cor_Coe_1d
+
+end interface
+
+interface stand_vari
+
+  module procedure stand_vari_1d
+
+end interface
+
+interface Reg_Line
+
+  module procedure Reg_Line_1d
+
+end interface
+
+
 contains
 
 subroutine Mean_1d( x, ave, error )  ! 1 ʿͷ׻롼
@@ -256,8 +293,10 @@ subroutine Anomaly_3d( x, anor, error )  ! 3 ǡк֤
 
 end subroutine Anomaly_3d
 
+!---------------------------------------
+!---------------------------------------
 
-subroutine stand_vari( x, anor, error )  ! 1 ǡɸк׻
+subroutine stand_vari_1d( x, anor, error )  ! 1 ǡɸк׻
   ! ɸк$\sigma $,
   ! $$\sigma =\sum^{nx}_{i=1}{epsilon ^2} $$
   ! , $\epsilon $ʿͤΤ$x-\bar{x}$Ǥ.
@@ -286,9 +325,84 @@ subroutine stand_vari( x, anor, error )  ! 1 ǡɸк׻
      end do
   end if
 
-end subroutine stand_vari
+end subroutine stand_vari_1d
 
-subroutine covariance( x, y, cov, error )  ! 2 Ĥ 1 ǡζʬ׻
+!---------------------------------------
+!---------------------------------------
+
+subroutine stand_vari_2d( x, anor, error )  ! 2 ǡɸк׻
+  implicit none
+  real, intent(in) :: x(:,:)  ! ǡ
+  real, intent(inout) :: anor  ! ɸк
+  real, intent(in), optional :: error  ! »
+  integer :: i, j, counter
+  integer :: nx  ! ǡ 1
+  integer :: ny  ! ǡ 2
+  real :: val(size(x,1)*size(x,2))
+
+  nx=size(x,1)
+  ny=size(x,2)
+
+  counter=0
+  do j=1,ny
+     do i=1,nx
+        counter=counter+1
+        val(counter)=x(i,j)
+     end do
+  end do
+
+  anor=0.0
+
+  if(present(error))then
+     call stand_vari_1d( val, anor, error )
+  else
+     call stand_vari_1d( val, anor )
+  end if
+
+end subroutine stand_vari_2d
+
+!---------------------------------------
+!---------------------------------------
+
+subroutine stand_vari_3d( x, anor, error )  ! 3 ǡɸк׻
+  implicit none
+  real, intent(in) :: x(:,:,:)  ! ǡ
+  real, intent(inout) :: anor  ! ɸк
+  real, intent(in), optional :: error  ! »
+  integer :: i, j, k, counter
+  integer :: nx  ! ǡ 1
+  integer :: ny  ! ǡ 2
+  integer :: nz  ! ǡ 3
+  real :: val(size(x,1)*size(x,2)*size(x,3))
+
+  nx=size(x,1)
+  ny=size(x,2)
+  nz=size(x,3)
+
+  counter=0
+  do k=1,nz
+     do j=1,ny
+        do i=1,nx
+           counter=counter+1
+           val(counter)=x(i,j,k)
+        end do
+     end do
+  end do
+
+  anor=0.0
+
+  if(present(error))then
+     call stand_vari_1d( val, anor, error )
+  else
+     call stand_vari_1d( val, anor )
+  end if
+
+end subroutine stand_vari_3d
+
+!---------------------------------------
+!---------------------------------------
+
+subroutine covariance_1d( x, y, cov, error )  ! 2 Ĥ 1 ǡζʬ׻
   ! ʬ$\sigma $,
   ! $$\sigma =\sum^{nx}_{i=1}{(x-\bar{x})(y-\bar{y})} $$
   implicit none
@@ -319,10 +433,90 @@ subroutine covariance( x, y, cov, error )  ! 2 Ĥ 1 ǡζʬ׻
      end do
   end if
 
-end subroutine covariance
+end subroutine covariance_1d
 
+!---------------------------------------
+!---------------------------------------
 
-subroutine nearest_search_1d( x, point, i )
+subroutine covariance_2d( x, y, cov, error )  ! 2 Ĥ 2 ǡζʬ׻
+  implicit none
+  real, intent(in) :: x(:,:)  ! ǡ 1
+  real, intent(in) :: y(size(x,1),size(x,2))  ! ǡ 2
+  real, intent(inout) :: cov  ! ɸк
+  real, intent(in), optional :: error  ! »
+  integer :: i, j, counter
+  integer :: nx  ! ǡ 1
+  integer :: ny  ! ǡ 2
+  real :: val1(size(x,1)*size(x,2)), val2(size(x,1)*size(x,2))
+
+  nx=size(x,1)
+  ny=size(x,2)
+
+  counter=0
+
+  do j=1,ny
+     do i=1,nx
+        counter=counter+1
+        val1(counter)=x(i,j)
+        val2(counter)=y(i,j)
+     end do
+  end do
+
+  cov=0.0
+
+  if(present(error))then
+     call covariance_1d( val1, val2, cov, error )
+  else
+     call covariance_1d( val1, val2, cov )
+  end if
+
+end subroutine covariance_2d
+
+!---------------------------------------
+!---------------------------------------
+
+subroutine covariance_3d( x, y, cov, error )  ! 2 Ĥ 3 ǡζʬ׻
+  implicit none
+  real, intent(in) :: x(:,:,:)  ! ǡ 1
+  real, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! ǡ 2
+  real, intent(inout) :: cov  ! ɸк
+  real, intent(in), optional :: error  ! »
+  integer :: i, j, k, counter
+  integer :: nx  ! ǡ 1
+  integer :: ny  ! ǡ 2
+  integer :: nz  ! ǡ 3
+  real :: val1(size(x,1)*size(x,2)*size(x,3)), val2(size(x,1)*size(x,2)*size(x,3))
+
+  nx=size(x,1)
+  ny=size(x,2)
+  nz=size(x,3)
+
+  counter=0
+
+  do k=1,nz
+     do j=1,ny
+        do i=1,nx
+           counter=counter+1
+           val1(counter)=x(i,j,k)
+           val2(counter)=y(i,j,k)
+        end do
+     end do
+  end do
+
+  cov=0.0
+
+  if(present(error))then
+     call covariance_1d( val1, val2, cov, error )
+  else
+     call covariance_1d( val1, val2, cov )
+  end if
+
+end subroutine covariance_3d
+
+!---------------------------------------
+!---------------------------------------
+
+subroutine nearest_search_1d( x, point, i, hx, hp )
   ! 1 Ƕ˵õ롼
   ! interpo_search_1d ͤ, ͤ +1 ͤεΥӤ
   ! Υû򤹤.
@@ -330,6 +524,8 @@ subroutine nearest_search_1d( x, point, i )
   real, intent(in) :: x(:)  ! 
   real, intent(in) :: point  ! 
   integer, intent(inout) :: i  ! point κǶ˵ֹ
+  real, intent(in), optional :: hx(size(x))  ! x ɸΥ
+  real, intent(in), optional :: hp  ! point ǤΥ !! ޤѰդ
   real :: tmp1, tmp2
   integer :: j, nx
 
@@ -507,25 +703,37 @@ subroutine interpo_search_3d( x, y, z, pointx, pointy, pointz, i, j, k, undeff )
 end subroutine interpo_search_3d
 
 
-subroutine interpolation_1d( x, y, point, val )
+subroutine interpolation_1d( x, y, point, val, h, hp )
   ! 1 ޥ롼
   implicit none
   real, intent(in) :: x(2)  ! κü
   real, intent(in) :: y(2)  ! x Ƥ
   real, intent(in) :: point  ! 
   real, intent(inout) :: val  ! Ǥ
+  real, intent(in), optional :: h(2)  ! κǤΥ
+  real, intent(in), optional :: hp  ! ǤΥ
   real :: fd, dt
   real :: tmin
   real :: tmax
   real :: xmin
   real :: xmax
 
-  tmin=x(1)
-  tmax=x(2)
+  if(present(h))then
+     tmin=x(1)*h(1)
+     tmax=x(2)*h(2)
+  else
+     tmin=x(1)
+     tmax=x(2)
+  end if
+
   xmin=y(1)
   xmax=y(2)
 
-  dt=point-tmin
+  if(present(hp))then
+     dt=hp*point-tmin
+  else
+     dt=point-tmin
+  end if
 
   fd=(xmax-xmin)/(tmax-tmin)
 
@@ -533,7 +741,7 @@ subroutine interpolation_1d( x, y, point, val )
 end subroutine interpolation_1d
 
 
-subroutine interpolation_2d( x, y, z, point, val )
+subroutine interpolation_2d( x, y, z, point, val, h, hp )
   ! 2 νޥ롼
   ! ܥ롼ľľɸ֤ǤΤ߻Ѳǽ.
   implicit none
@@ -542,21 +750,36 @@ subroutine interpolation_2d( x, y, z, point, val )
   real, intent(in) :: z(2,2)  ! x, y ǤγǤ, (i,j) ˤĤ, i<=x, j<=y
   real, intent(in) :: point(2)  !  point(1)<=x ɸ, point(2)<=y ɸ
   real, intent(inout) :: val  ! Ǥ
+  real, intent(in), optional :: h(2,2)  ! λͶǤΥ
+  real, intent(in), optional :: hp(2)  ! ǤΥ
   real :: valx(2)
 
-  ! y(1) Ǥ x Ǥ
-  call interpolation_1d( (/x(1), x(2)/), (/z(1,1), z(2,1)/), point(1), valx(1) )
+  if(present(h))then
+     ! y(1) Ǥ x Ǥ
+     call interpolation_1d( x, (/z(1,1), z(2,1)/), point(1), valx(1),  &
+  &                         (/h(1,1), h(2,1)/), hp(1) )
 
-  ! y(2) Ǥ x Ǥ
-  call interpolation_1d( (/x(1), x(2)/), (/z(1,2), z(2,2)/), point(1), valx(2) )
+     ! y(2) Ǥ x Ǥ
+     call interpolation_1d( x, (/z(1,2), z(2,2)/), point(1), valx(2),  &
+  &                         (/h(1,2), h(2,2)/), hp(1) )
+   
+     ! x  y Ǥ(줬)
+     call interpolation_1d( y, valx, point(2), val, (/h(1,1), h(1,2)/), hp(2) )
+  else
+     ! y(1) Ǥ x Ǥ
+     call interpolation_1d( x, (/z(1,1), z(2,1)/), point(1), valx(1) )
 
-  ! x  y Ǥ(줬)
-  call interpolation_1d( (/y(1), y(2)/), (/valx(1), valx(2)/), point(2), val )
+     ! y(2) Ǥ x Ǥ
+     call interpolation_1d( x, (/z(1,2), z(2,2)/), point(1), valx(2) )
+   
+     ! x  y Ǥ(줬)
+     call interpolation_1d( y, valx, point(2), val )
+  end if
 
 end subroutine interpolation_2d
 
 
-subroutine interpolation_3d( x, y, z, u, point, val )
+subroutine interpolation_3d( x, y, z, u, point, val, h, hp )
   ! 3 νޥ롼
   ! ܥ롼ľľɸ֤ǤΤ߻Ѳǽ.
   implicit none
@@ -566,16 +789,31 @@ subroutine interpolation_3d( x, y, z, u, point, val )
   real, intent(in) :: u(2,2,2)  ! x, y, z ǤγǤ, (i,j,k) ˤĤ, i<=x, j<=y, k<=z
   real, intent(in) :: point(3)  !  point(1)<=x ɸ, point(2)<=y ɸ, point(3)<=z ɸ
   real, intent(inout) :: val  ! Ǥ
+  real, intent(in), optional :: h(2,2,2)  ! ȬǤΥ
+  real, intent(in), optional :: hp(3)  ! ǤΥ
   real :: valx(2)
 
-  ! z(1) Ǥ x-y ʿ̤Ǥνޤ
-  call interpolation_2d( x, y, u(:,:,1), point(1:2), valx(1) )
-
-  ! z(2) Ǥ x Ǥ
-  call interpolation_2d( x, y, u(:,:,2), point(1:2), valx(2) )
-
-  ! z(1)  z Ǥ(줬)
-  call interpolation_1d( (/z(1), z(2)/), (/valx(1), valx(2)/), point(3), val )
+  if(present(h))then
+     ! z(1) Ǥ x-y ʿ̤Ǥνޤ
+     call interpolation_2d( x, y, u(:,:,1), point(1:2), valx(1),  &
+  &                         h(:,:,1), hp(1:2) )
+   
+     ! z(2) Ǥ x Ǥ
+     call interpolation_2d( x, y, u(:,:,2), point(1:2), valx(2),  &
+  &                         h(:,:,2), hp(1:2) )
+   
+     ! z(1)  z Ǥ(줬)
+     call interpolation_1d( z, valx, point(3), val, h(1,1,:), hp(3) )
+  else
+     ! z(1) Ǥ x-y ʿ̤Ǥνޤ
+     call interpolation_2d( x, y, u(:,:,1), point(1:2), valx(1) )
+   
+     ! z(2) Ǥ x Ǥ
+     call interpolation_2d( x, y, u(:,:,2), point(1:2), valx(2) )
+   
+     ! z(1)  z Ǥ(줬)
+     call interpolation_1d( (/z(1), z(2)/), (/valx(1), valx(2)/), point(3), val )
+  end if
 
 end subroutine interpolation_3d
 
@@ -590,26 +828,26 @@ subroutine auto_interpolation_1d( x, r, u, v, undef )
   real, intent(in) :: r(:)  ! ޺ɸ
   real, intent(in) :: u(size(x))  ! ǡ
   real, intent(inout) :: v(size(r))  ! ޤǡ
-  integer, intent(in), optional :: undef  ! ̤
-  integer :: i, nx, nr, ix, ir
-  integer :: defun
-
-  if(present(undef))then
-     defun=undef
-  else
-     defun=0
-  end if
+  real, intent(in), optional :: undef  ! ̤
+  integer :: i, nx, nr, ir
+  real :: defun
 
   nx=size(x)
   nr=size(r)
 
-  do i=1, nr
-     call interpo_search_1d( x, r(i), ir, defun )
+  if(present(undef))then
+     defun=undef
+  else
+     defun=0.0
+  end if
 
-     if(ir/=defun.and.ir<nx)then
+  do i=1, nr
+     call interpo_search_1d( x, r(i), ir, int(defun) )
+
+     if(ir/=int(defun).and.ir<nx)then
         call interpolation_1d( x(ir:ir+1), u(ir:ir+1), r(i), v(i) )
      else
-        v(i)=real(defun)
+        v(i)=defun
      end if
   end do
 
@@ -628,30 +866,30 @@ subroutine auto_interpolation_2d( x, y, r, q, u, v, undef )
   real, intent(in) :: q(:)  ! ޺ɸ 2
   real, intent(in) :: u(size(x),size(y))  ! ǡ
   real, intent(inout) :: v(size(r),size(q))  ! ޤǡ
-  integer, intent(in), optional :: undef  ! ̤
-  integer :: i, j, nx, ny, nr, nq, ix, iy, ir, iq
-  integer :: defun
-
-  if(present(undef))then
-     defun=undef
-  else
-     defun=0
-  end if
+  real, intent(in), optional :: undef  ! ̤
+  integer :: i, j, nx, ny, nr, nq, ir, iq
+  real :: defun
 
   nx=size(x)
   ny=size(y)
   nr=size(r)
   nq=size(q)
 
+  if(present(undef))then
+     defun=undef
+  else
+     defun=0.0
+  end if
+
   do j=1, nq
      do i=1, nr
-        call interpo_search_2d( x, y, r(i), q(j), ir, iq, defun )
+        call interpo_search_2d( x, y, r(i), q(j), ir, iq, int(defun) )
 
-        if(ir/=defun.and.iq/=defun.and.ir<nx.and.iq<ny)then
+        if(ir/=int(defun).and.iq/=int(defun).and.ir<nx.and.iq<ny)then
            call interpolation_2d( x(ir:ir+1), y(iq:iq+1),  &
   &                               u(ir:ir+1,iq:iq+1), (/r(i), q(j)/), v(i,j) )
         else
-           v(i,j)=real(defun)
+           v(i,j)=defun
         end if
      end do
   end do
@@ -673,15 +911,9 @@ subroutine auto_interpolation_3d( x, y, z, r, q, p, u, v, undef )
   real, intent(in) :: p(:)  ! ޺ɸ 3
   real, intent(in) :: u(size(x),size(y),size(z))  ! ǡ
   real, intent(inout) :: v(size(r),size(q),size(p))  ! ޤǡ
-  integer, intent(in), optional :: undef  ! ̤
-  integer :: i, j, k, nx, ny, nz, nr, nq, np, ix, iy, iz, ir, iq, ip
-  integer :: defun
-
-  if(present(undef))then
-     defun=undef
-  else
-     defun=0
-  end if
+  real, intent(in), optional :: undef  ! ̤
+  integer :: i, j, k, nx, ny, nz, nr, nq, np, ir, iq, ip
+  real :: defun
 
   nx=size(x)
   ny=size(y)
@@ -690,19 +922,25 @@ subroutine auto_interpolation_3d( x, y, z, r, q, p, u, v, undef )
   nq=size(q)
   np=size(p)
 
+  if(present(undef))then
+     defun=undef
+  else
+     defun=0.0
+  end if
+
   do k=1, np
      do j=1, nq
         do i=1, nr
            call interpo_search_3d( x, y, z, r(i), q(j), p(k),  &
-  &                                ir, iq, ip, defun )
+  &                                ir, iq, ip, int(defun) )
 
-           if(ir/=defun.and.iq/=defun.and.ip/=defun.and.  &
+           if(ir/=int(defun).and.iq/=int(defun).and.ip/=int(defun).and.  &
   &           ir<nx.and.iq<ny.and.ip<nz)then
               call interpolation_3d( x(ir:ir+1), y(iq:iq+1), z(ip:ip+1),  &
   &                               u(ir:ir+1,iq:iq+1,ip:ip+1),  &
   &                               (/r(i), q(j), p(k)/), v(i,j,k) )
            else
-              v(i,j,k)=real(defun)
+              v(i,j,k)=defun
            end if
         end do
      end do
@@ -713,7 +951,7 @@ end subroutine auto_interpolation_3d
 !------------------------------------
 !------------------------------------
 
-subroutine LSM( x, y, slope, intercept, undef )  ! Ǿˡˤ뷹ҷ׻
+subroutine LSM_1d( x, y, slope, intercept, undef )  ! Ǿˡˤ뷹ҷ׻ (1 ǡ)
   implicit none
   real, intent(in) :: x(:)  ! ǡ 1
   real, intent(in) :: y(size(x))  ! ǡ 2
@@ -738,20 +976,103 @@ subroutine LSM( x, y, slope, intercept, undef )  ! Ǿˡˤ뷹ҷ׻
   end do
 !$omp end parallel do
 
-  call summ(v,a,undef)
-  call summ(x,b,undef)
-  call summ(y,c,undef)
-  call summ(u,d,undef)
+  if(present(undef))then
+     call summ(v,a,undef)
+     call summ(x,b,undef)
+     call summ(y,c,undef)
+     call summ(u,d,undef)
+  else
+     call summ(v,a)
+     call summ(x,b)
+     call summ(y,c)
+     call summ(u,d)
+  end if
 
   slope=(nx*a-b*c)/(nx*d-b**2)
   intercept=(c*d-a*b)/(nx*d-b**2)
 
-end subroutine LSM
+end subroutine LSM_1d
 
 !------------------------------------
 !------------------------------------
 
-subroutine LSM_poly( x, y, a, intercept, undef )
+subroutine LSM_2d( x, y, slope, intercept, undef )  ! Ǿˡˤ뷹ҷ׻ (2 ǡ)
+  implicit none
+  real, intent(in) :: x(:,:)  ! ǡ 1
+  real, intent(in) :: y(size(x,1),size(x,2))  ! ǡ 2
+  real, intent(inout) :: slope  ! Ŭʷ
+  real, intent(inout) :: intercept  ! Ŭ
+  real, intent(in), optional :: undef ! undef 
+  real :: u(size(x,1)*size(x,2)), v(size(x,1)*size(x,2))
+  integer :: i, j, counter
+  integer :: nx  ! ǡ 1
+  integer :: ny  ! ǡ 2
+
+  nx=size(x,1)
+  ny=size(x,2)
+
+  counter=0
+
+  do j=1,ny
+     do i=1,nx
+        counter=counter+1
+        u(counter)=x(i,j)
+        v(counter)=y(i,j)
+     end do
+  end do
+
+  if(present(undef))then
+     call LSM_1d( u, v, slope, intercept, undef )
+  else
+     call LSM_1d( u, v, slope, intercept )
+  end if
+
+end subroutine LSM_2d
+
+!------------------------------------
+!------------------------------------
+
+subroutine LSM_3d( x, y, slope, intercept, undef )  ! Ǿˡˤ뷹ҷ׻ (3 ǡ)
+  implicit none
+  real, intent(in) :: x(:,:,:)  ! ǡ 1
+  real, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! ǡ 2
+  real, intent(inout) :: slope  ! Ŭʷ
+  real, intent(inout) :: intercept  ! Ŭ
+  real, intent(in), optional :: undef ! undef 
+  real :: u(size(x,1)*size(x,2)*size(x,3)), v(size(x,1)*size(x,2)*size(x,3))
+  integer :: i, j, k, counter
+  integer :: nx  ! ǡ 1
+  integer :: ny  ! ǡ 2
+  integer :: nz  ! ǡ 3
+
+  nx=size(x,1)
+  ny=size(x,2)
+  nz=size(x,3)
+
+  counter=0
+
+  do k=1,nz
+     do j=1,ny
+        do i=1,nx
+           counter=counter+1
+           u(counter)=x(i,j,k)
+           v(counter)=y(i,j,k)
+        end do
+     end do
+  end do
+
+  if(present(undef))then
+     call LSM_1d( u, v, slope, intercept, undef )
+  else
+     call LSM_1d( u, v, slope, intercept )
+  end if
+
+end subroutine LSM_3d
+
+!------------------------------------
+!------------------------------------
+
+subroutine LSM_poly_1d( x, y, a, intercept, undef )
 ! LSM ¿༰С.
 ! LSM Ǥ, F(x)=a_0+a_1x ľԤäƤ,
 ! LSM_poly Ǥ, F(x)=\sum^{N}_{n=0}{a_nx^n}
@@ -841,29 +1162,204 @@ subroutine LSM_poly( x, y, a, intercept, undef )
   end do
   intercept=coe(0)
 
-end subroutine
+end subroutine LSM_poly_1d
 
+!------------------------------------
 !------------------------------------
 
-subroutine Reg_Line( x, y, slope, intercept )
+subroutine LSM_poly_2d( x, y, a, intercept, undef )
+! LSM ¿༰С. (2 ǡ)
+  use Matrix_Calc
+  implicit none
+  real, intent(in) :: x(:,:)  ! ǡ 1
+  real, intent(in) :: y(size(x,1),size(x,2))  ! ǡ 2
+  real, intent(inout) :: a(:)  ! ¿༰η
+  real, intent(inout) :: intercept  ! y . 
+                         ! a Ȥ߹ȰϤȤ, poly_n+1 Ϥɬפ
+                         ! , ʶ路ȽǤ, a_0 Ǥ y Ҥ
+                         ! ΩǰȤϤȤˤ.
+  real, intent(in), optional :: undef  ! ̤.
+  integer :: i, j, counter
+  integer :: nx  ! ǡθĿ 1
+  integer :: ny  ! ǡθĿ 2
+  real, dimension(size(x,1)*size(x,2)) :: val1, val2
+
+  nx=size(x,1)
+  ny=size(x,2)
+
+  counter=0
+
+  do j=1,ny
+     do i=1,nx
+        counter=counter+1
+        val1(counter)=x(i,j)
+        val2(counter)=y(i,j)
+     end do
+  end do
+
+  if(present(undef))then
+     call LSM_poly_1d( val1, val2, a, intercept, undef )
+  else
+     call LSM_poly_1d( val1, val2, a, intercept )
+  end if
+
+end subroutine LSM_poly_2d
+
+!------------------------------------
+!------------------------------------
+
+subroutine LSM_poly_3d( x, y, a, intercept, undef )
+! LSM ¿༰С. (3 ǡ)
+  use Matrix_Calc
+  implicit none
+  real, intent(in) :: x(:,:,:)  ! ǡ 1
+  real, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! ǡ 2
+  real, intent(inout) :: a(:)  ! ¿༰η
+  real, intent(inout) :: intercept  ! y . 
+                         ! a Ȥ߹ȰϤȤ, poly_n+1 Ϥɬפ
+                         ! , ʶ路ȽǤ, a_0 Ǥ y Ҥ
+                         ! ΩǰȤϤȤˤ.
+  real, intent(in), optional :: undef  ! ̤.
+  integer :: i, j, k, counter
+  integer :: nx  ! ǡθĿ 1
+  integer :: ny  ! ǡθĿ 2
+  integer :: nz  ! ǡθĿ 3
+  real, dimension(size(x,1)*size(x,2)*size(x,3)) :: val1, val2
+
+  nx=size(x,1)
+  ny=size(x,2)
+  ny=size(x,3)
+
+  counter=0
+
+  do k=1,nz
+     do j=1,ny
+        do i=1,nx
+           counter=counter+1
+           val1(counter)=x(i,j,k)
+           val2(counter)=y(i,j,k)
+        end do
+     end do
+  end do
+
+  if(present(undef))then
+     call LSM_poly_1d( val1, val2, a, intercept, undef )
+  else
+     call LSM_poly_1d( val1, val2, a, intercept )
+  end if
+
+end subroutine LSM_poly_3d
+
+!------------------------------------
+!------------------------------------
+
+subroutine Reg_Line_1d( x, y, slope, intercept, undef )
   ! LSM ѤƲľη slope  intercept ׻롼
   implicit none
   real, intent(in) :: x(:)  ! ǡ 1
   real, intent(in) :: y(size(x))  ! ǡ 2
   real, intent(inout) :: slope  ! Ŭʷ
   real, intent(inout) :: intercept  ! Ŭ
+  real, intent(in), optional :: undef  ! ̤
   real :: u(size(x)), v(size(x))
   integer :: nx  ! ǡ
 
   nx=size(x)
 
-  call Anomaly_1d( x, u )
-  call Anomaly_1d( y, v )
-  call LSM( u, v, slope, intercept )
+  if(present(undef))then
+     call Anomaly_1d( x, u, undef )
+     call Anomaly_1d( y, v, undef )
+     call LSM( u, v, slope, intercept, undef )
+  else
+     call Anomaly_1d( x, u )
+     call Anomaly_1d( y, v )
+     call LSM( u, v, slope, intercept )
+  end if
 
-end subroutine
+end subroutine Reg_Line_1d
 
-subroutine Cor_Coe( x, y ,cc, error )  ! 2 ǡط׻롼
+!------------------------------------
+!------------------------------------
+
+subroutine Reg_Line_2d( x, y, slope, intercept, error )
+  ! LSM ѤƲľη slope  intercept ׻롼 (2 )
+  implicit none
+  real, intent(in) :: x(:,:)  ! ǡ 1
+  real, intent(in) :: y(size(x,1),size(x,2))  ! ǡ 2
+  real, intent(inout) :: slope  ! Ŭʷ
+  real, intent(inout) :: intercept  ! Ŭ
+  real, intent(in), optional :: error
+  real, dimension(size(x,1)*size(x,2)) :: u, v
+  integer :: i, j, counter
+  integer :: nx  ! ǡ 1
+  integer :: ny  ! ǡ 2
+
+  nx=size(x,1)
+  ny=size(x,2)
+
+  counter=0
+
+  do j=1,ny
+     do i=1,nx
+        counter=counter+1
+        u(counter)=x(i,j)
+        v(counter)=y(i,j)
+     end do
+  end do
+
+  if(present(error))then
+     call Reg_Line_1d( u, v, slope, intercept, error )
+  else
+     call Reg_Line_1d( u, v, slope, intercept )
+  end if
+
+end subroutine Reg_Line_2d
+
+!------------------------------------
+!------------------------------------
+
+subroutine Reg_Line_3d( x, y, slope, intercept, error )
+  ! LSM ѤƲľη slope  intercept ׻롼 (3 )
+  implicit none
+  real, intent(in) :: x(:,:,:)  ! ǡ 1
+  real, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! ǡ 2
+  real, intent(inout) :: slope  ! Ŭʷ
+  real, intent(inout) :: intercept  ! Ŭ
+  real, intent(in), optional :: error
+  real, dimension(size(x,1)*size(x,2)*size(x,3)) :: u, v
+  integer :: i, j, k, counter
+  integer :: nx  ! ǡ 1
+  integer :: ny  ! ǡ 2
+  integer :: nz  ! ǡ 3
+
+  nx=size(x,1)
+  ny=size(x,2)
+  nz=size(x,3)
+
+  counter=0
+
+  do k=1,nz
+     do j=1,ny
+        do i=1,nx
+           counter=counter+1
+           u(counter)=x(i,j,k)
+           v(counter)=y(i,j,k)
+        end do
+     end do
+  end do
+
+  if(present(error))then
+     call Reg_Line_1d( u, v, slope, intercept, error )
+  else
+     call Reg_Line_1d( u, v, slope, intercept )
+  end if
+
+end subroutine Reg_Line_3d
+
+!------------------------------------
+!------------------------------------
+
+subroutine Cor_Coe_1d( x, y ,cc, error )  ! 2 ǡط׻롼
   implicit none
   real, intent(in) :: x(:)  ! ǡ 1
   real, intent(in) :: y(size(x))  ! ǡ 2
@@ -886,7 +1382,81 @@ subroutine Cor_Coe( x, y ,cc, error )  ! 2 ǡط׻롼
 
   cc=cov/(sqrt(anor1)*sqrt(anor2))
 
-end subroutine Cor_Coe
+end subroutine Cor_Coe_1d
+
+!---------------------------------
+!------------------------------------
+
+subroutine Cor_Coe_2d( x, y ,cc, error )  ! 2 ǡط׻롼 (2 )
+  implicit none
+  real, intent(in) :: x(:,:)  ! ǡ 1
+  real, intent(in) :: y(size(x,1),size(x,2))  ! ǡ 2
+  real, intent(inout) :: cc  ! ط
+  real, intent(in), optional :: error  ! »
+  integer :: i, j, counter
+  integer :: nx  ! ǡĿ 1
+  integer :: ny  ! ǡĿ 2
+  real, dimension(size(x,1)*size(x,2)) :: val1, val2
+
+  nx=size(x,1)
+  ny=size(x,2)
+
+  counter=0
+
+  do j=1,ny
+     do i=1,nx
+        counter=counter+1
+        val1(counter)=x(i,j)
+        val2(counter)=y(i,j)
+     end do
+  end do
+
+  if(present(error))then
+     call Cor_Coe_1d( val1, val2, cc, error )
+  else
+     call Cor_Coe_1d( val1, val2, cc )
+  end if
+
+end subroutine Cor_Coe_2d
+
+!---------------------------------
+!------------------------------------
+
+subroutine Cor_Coe_3d( x, y ,cc, error )  ! 2 ǡط׻롼 (3 )
+  implicit none
+  real, intent(in) :: x(:,:,:)  ! ǡ 1
+  real, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! ǡ 2
+  real, intent(inout) :: cc  ! ط
+  real, intent(in), optional :: error  ! »
+  integer :: i, j, k, counter
+  integer :: nx  ! ǡĿ 1
+  integer :: ny  ! ǡĿ 2
+  integer :: nz  ! ǡĿ 2
+  real, dimension(size(x,1)*size(x,2)*size(x,3)) :: val1, val2
+
+  nx=size(x,1)
+  ny=size(x,2)
+  nz=size(x,3)
+
+  counter=0
+
+  do k=1,nz
+     do j=1,ny
+        do i=1,nx
+           counter=counter+1
+           val1(counter)=x(i,j,k)
+           val2(counter)=y(i,j,k)
+        end do
+     end do
+  end do
+
+  if(present(error))then
+     call Cor_Coe_1d( val1, val2, cc, error )
+  else
+     call Cor_Coe_1d( val1, val2, cc )
+  end if
+
+end subroutine Cor_Coe_3d
 
 !---------------------------------
 !---------------------------------
