@@ -28,7 +28,7 @@ subroutine tangent_mean_scal( x, y, xc, yc, u, r, theta, v )
   real, intent(in) :: r(:)  ! ʿѲȤưκɸ(xc ͤ).
   real, intent(in) :: theta(:)  ! ʿѲȤκɸ [rad].
   real, intent(inout) :: v(size(r))  ! ʿѲ u .
-  integer :: i, j, k, nx, ny, nr, nt
+  integer :: i, j, nx, ny, nr, nt
   real :: work(size(r),size(theta))
   real :: point(size(r),size(theta),2)
   integer :: ip(size(r),size(theta),2)
@@ -132,7 +132,7 @@ subroutine tangent_mean_anom_scal( x, y, xc, yc, u, r, theta, v )
   real, intent(in) :: r(:)  ! ʿѲȤưκɸ(xc ͤ).
   real, intent(in) :: theta(:)  ! ʿѲȤκɸ [rad].
   real, intent(inout) :: v(size(r),size(theta))  ! ʿѲ u ΥΥޥ꡼.
-  integer :: i, j, k, nx, ny, nr, nt
+  integer :: i, j, nx, ny, nr, nt
   real :: work(size(r),size(theta))
   real :: point(size(r),size(theta),2)
   integer :: ip(size(r),size(theta),2)
@@ -225,7 +225,7 @@ subroutine tangent_mean_anom_scal_Cart( x, y, xc, yc, scal, r, theta, scal_anom,
   real, intent(in) :: theta(:)  ! ʿѲȤκɸ [rad].
   real, intent(inout) :: scal_anom(size(x),size(y))  ! ǥȷϤǤΥΥޥ.
   real, optional :: undef  ! ͤĤʤȤ̤. ǥեȤǤ dcl ̤
-  integer :: i, j, k, nx, ny, nr, nt, itmpr
+  integer :: j, k, nx, ny, nr, nt, itmpr
   real :: tmp(size(r))
   real :: tmpr, tmp_anom, undeff
 
@@ -292,7 +292,7 @@ subroutine tangent_mean_vec( charc, x, y, xc, yc, u1, u2, r, theta, v )
   real, intent(in) :: r(:)  ! ʿѲȤưκɸ(xc ͤ).
   real, intent(in) :: theta(:)  ! ʿѲȤκɸ [rad].
   real, intent(inout) :: v(size(r))  ! ʿѲ u .
-  integer :: i, j, k, nx, ny, nr, nt
+  integer :: i, j, nx, ny, nr, nt
   real :: work1(size(r),size(theta),1), work2(size(r),size(theta),1), work3(size(r),size(theta),1)
   real :: posx(size(r),size(theta),1), posy(size(r),size(theta),1), posz(size(r),size(theta),1)
   real :: vecx(size(r),size(theta),1), vecy(size(r),size(theta),1), vecz(size(r),size(theta),1)
@@ -442,7 +442,7 @@ subroutine tangent_mean_anom_vec( charc, x, y, xc, yc, u1, u2, r, theta, v )
   real, intent(in) :: r(:)  ! ʿѲȤưκɸ(xc ͤ).
   real, intent(in) :: theta(:)  ! ʿѲȤκɸ [rad].
   real, intent(inout) :: v(size(r),size(theta))  ! Υޥ u .
-  integer :: i, j, k, nx, ny, nr, nt
+  integer :: i, j, nx, ny, nr, nt
   real :: work1(size(r),size(theta),1), work2(size(r),size(theta),1), work3(size(r),size(theta),1)
   real :: posx(size(r),size(theta),1), posy(size(r),size(theta),1), posz(size(r),size(theta),1)
   real :: vecx(size(r),size(theta),1), vecy(size(r),size(theta),1), vecz(size(r),size(theta),1)
@@ -584,7 +584,7 @@ subroutine tangent_mean_turb( signal, r, z, u, v, w, rho, nuh, nuv, val, undef,
   real, intent(in), optional :: sfctau(size(r))  ! ɽ̤Υեå
                  ! 줬Ϳ, ǲؤαϤϤ֤.
   integer :: i   ! 졼ź
-  integer :: j   ! 졼ź
+!  integer :: j   ! 졼ź
   integer :: k   ! 졼ź
   integer :: id   ! 졼ź
   integer :: nr  ! ǿ 1 
@@ -670,15 +670,12 @@ subroutine tangent_mean_Reynolds( signal, r, z, u, v, w, rho, nuh, nuv, val, und
   real, intent(in), optional :: sfctau(size(r))  ! ɽ̤Υեå
                  ! 줬Ϳ, ǲؤαϤϤ֤.
   integer :: i   ! 졼ź
-  integer :: j   ! 졼ź
+!  integer :: j   ! 졼ź
   integer :: k   ! 졼ź
   integer :: nr  ! ǿ 1 
   integer :: nz  ! ǿ 3 
   real :: dr  ! 1 ܤʬʻҴֳ [m]
   real :: dz  ! 3 ܤʬʻҴֳ [m]
-  real, dimension(size(r),size(z)) :: tau1, tau2, tau3  ! signal 
-              ! Ѥ 1,2,3 ̤˿ľʱ
-  integer :: signaltau
   real :: sxx(size(r),size(z)), nu(size(r),size(z))
   real :: stau(size(r))
 
@@ -860,8 +857,6 @@ subroutine tangent_mean_deform( signal, r, z, u, v, w, val, undef )
   integer :: nz  ! ǿ 2 
   real :: dr  ! 1 ܤʬʻҴֳ [m]
   real :: dz  ! 2 ܤʬʻҴֳ [m]
-  real, dimension(size(r),size(z)) :: tau1, tau2, tau3  ! signal 
-              ! Ѥ 1,2,3 ̤˿ľʱ
 
   dr=r(2)-r(1)
   dz=z(2)-z(1)
@@ -964,7 +959,7 @@ subroutine hydro_grad_eqb( r, z, coril, v, pres_s, rho_s, pres, rho, error )
   real, intent(inout) :: rho(size(r),size(z))  ! ʿվ̩ [kg/m^3]
   real :: old_pres(size(r),size(z)), old_rho(size(r),size(z))
   integer :: nr, nz
-  integer :: i, j, k
+  integer :: i, j
   real :: err, err_tmp, err_max
 
   nr=size(r)
