@@ -29,7 +29,7 @@ subroutine Poisson_GauSei(x, y, rho, eps, boundary, psi, bound_opt,  &
   real, intent(in), optional :: e(size(x),size(y))  ! ʬη
                              ! Υޥ󶭳ξ : եå
   real, intent(inout) :: psi(size(x),size(y))  ! ݥβ
-  integer :: i, j, k, l, m, n
+  integer :: i, j
   integer :: nx  ! x 
   integer :: ny  ! y 
   integer :: signb, signd, signe  ! Ʒ׻뤫ɤ
@@ -853,7 +853,6 @@ subroutine Poisson_GauSei(x, y, rho, eps, boundary, psi, bound_opt,  &
 !-- ι
         if(err_max<=err)then
            err_max=err
-write(*,*) "### err", err_max, i, j, psi(i,j), tmp
         end if
 
         psi(i,j)=tmp
@@ -991,7 +990,7 @@ subroutine Poisson_Jacobi(x, y, rho, eps, boundary, psi, bound_opt,  &
   real, intent(in), optional :: d(size(x),size(y))  ! ʬη
   real, intent(in), optional :: e(size(x),size(y))  ! ʬη
   real, intent(inout) :: psi(size(x),size(y))  ! ݥβ
-  integer :: i, j, k, l, m, n
+  integer :: i, j
   integer :: nx  ! x 
   integer :: ny  ! y 
   integer :: signb, signd, signe  ! Ʒ׻뤫ɤ
