@@ -1,12 +1,14 @@
 module ffts
 ! fft ϢΥ֥롼
+  use Math_Const
 
 contains
 
-subroutine ffttp_1d( nx, a, b, csign, prim )
+subroutine ffttp_1d( nx, a, b, csign, prim, prim_fact, omega_fix, omegan_fix )
 !  Temperton's FFT
 !
 !  1d  fft  csign Ȥ, Ѵ, Ѵ롼
+  use Math_Const
   implicit none
   integer, intent(in) :: nx  ! ǿ
   complex, intent(in), dimension(0:nx-1) :: a  ! 
@@ -15,21 +17,26 @@ subroutine ffttp_1d( nx, a, b, csign, prim )
   character(1), optional, intent(in) :: prim  ! ǰʬ򤹤뤫ɤ
   ! [o=ʬ򤹤, x=ʬ򤷤ʤ] default=ʬ򤷤ʤ. ξ, ̾ DFT.
   ! ǰʬ򤹤, nx=2^a*3^b*5^c*7^d ޤǤʬ򤷤ʤ褦ˤ.
+  ! , 'x' ΤȤǤ, prim_fact ꤵƤ, Τ٤ FFT .
+  integer, dimension(5), optional :: prim_fact  ! prim = x ΤȤꤹ
+  ! Τ٤ FFT Ԥ. prim_fact=(/a,b,c,d,e/) : 2^a*3^b*5^c*7^d*e
+  complex, dimension(0:nx-1,0:nx-1), intent(in), optional :: omega_fix
+                       ! ;ǰбž
+  complex, dimension(0:nx-1,0:nx-1), intent(in), optional :: omegan_fix  ! ž
   integer, allocatable, dimension(:) :: l, m, n  ! κ
-  real, parameter :: pi=3.14159265
-  complex, parameter :: img=(0.0,1.0)
-  complex :: fact, ctmp
+  complex :: ctmp
   integer :: stat, counter, base
   integer :: i, j, k, id, jd, kd  ! do loop 
   integer, parameter, dimension(4) :: prim_dim=(/2, 3, 5, 7/)  ! ǰ
   integer, dimension(4) :: prim_num  ! ǰΤ٤
-  complex, dimension(0:1,0:1) :: omega2
-  complex, dimension(0:2,0:2) :: omega3
-  complex, dimension(0:4,0:4) :: omega5
-  complex, dimension(0:6,0:6) :: omega7
   complex, allocatable, dimension(:,:) :: omega
   complex, dimension(0:nx-1,0:nx-1) :: omegan
   complex, dimension(0:nx-1) :: c  ! tmp array
+  complex, dimension(0:1,0:1) :: omega2  ! ȿ 2 βž
+  complex, dimension(0:2,0:2) :: omega3  ! ȿ 3 βž
+  complex, dimension(0:4,0:4) :: omega5  ! ȿ 5 βž
+  complex, dimension(0:6,0:6) :: omega7  ! ȿ 7 βž
+
 
   base=nx
   prim_num=0
@@ -39,47 +46,58 @@ subroutine ffttp_1d( nx, a, b, csign, prim )
      b(i)=a(i)
   end do
 
+  if(real(romega2(1,1))/=-1.0.or.aimag(romega2(1,1))/=1.0.or.  &
+  &  real(iomega2(1,1))/=-1.0.or.aimag(iomega2(1,1))/=1.0)then
+     ! math_const  rotate_array 롼󤬷׻Ƥʤ, ư.
+     call rotate_array()
+  end if
+
 !-- ǰʬ򤹤
   if(present(prim))then
      if(prim=='o')then
-        do i=1,4
-           do while(mod(base,prim_dim(i))==0)
-              base=base/prim_dim(i)
-              prim_num(i)=prim_num(i)+1
-              counter=counter+1
+        if(present(prim_fact))then
+           do i=1,4
+!              if(prim_fact(i)==0)then
+!                 prim_num(i)=1
+!              else
+                 prim_num(i)=prim_fact(i)
+!              end if
+              counter=counter+prim_fact(i)
            end do
-        end do
-
+           base=prim_fact(5)
+        else
+           call prim_calc( nx, prim_num, base )
+           do i=1,4
+              counter=counter+prim_num(i)
+           end do
+        end if
+ 
         if(base==1)then
            counter=counter-1
         end if
-
+ 
         if(counter/=0)then  ! prim=='o' ǤäƤ, ǰʬǤʤ DFT .
            allocate(l(counter+1))
            allocate(m(counter+1))
            allocate(n(counter+1))
            stat=0
-
+           l=0
+           m=0
+           n=0
+   
            do i=1,4
               if(prim_num(i)/=0)then
                  select case(prim_dim(i))
                  case(2)
                     n(stat+1:stat+prim_num(i))=2
-                    stat=stat+prim_num(i)
-
                  case(3)
                     n(stat+1:stat+prim_num(i))=3
-                    stat=stat+prim_num(i)
-
                  case(5)
                     n(stat+1:stat+prim_num(i))=5
-                    stat=stat+prim_num(i)
-
                  case(7)
                     n(stat+1:stat+prim_num(i))=7
-                    stat=stat+prim_num(i)
-
                  end select
+                 stat=stat+prim_num(i)
               end if
            end do
            if(base/=1)then
@@ -91,95 +109,70 @@ subroutine ffttp_1d( nx, a, b, csign, prim )
 
 !-- ž
 
-  select case(csign)
-  case('r')
-     fact=cos(2.0*pi/real(nx))-img*sin(2.0*pi/real(nx))
-     if(counter/=0)then
-        omega2=1.0
-        omega2(1,1)=-1.0
+  if(counter/=0)then
+     select case (csign)
+     case ('r')
+        do j=0,1
+           do i=0,1
+              omega2(i,j)=romega2(i,j)
+           end do
+        end do
         do j=0,2
            do i=0,2
-              omega3(i,j)=cos(2.0*pi*i*j/3.0)-img*sin(2.0*pi*i*j/3.0)
+              omega3(i,j)=romega3(i,j)
            end do
         end do
         do j=0,4
            do i=0,4
-              omega5(i,j)=cos(2.0*pi*i*j/5.0)-img*sin(2.0*pi*i*j/5.0)
+              omega5(i,j)=romega5(i,j)
            end do
         end do
         do j=0,6
            do i=0,6
-              omega7(i,j)=cos(2.0*pi*i*j/7.0)-img*sin(2.0*pi*i*j/7.0)
+              omega7(i,j)=romega7(i,j)
            end do
         end do
-
-        if(base/=1)then
-           allocate(omega(0:base-1,0:base-1))
-           do j=0,base-1
-              do i=0,base-1
-                 omega(i,j)=cos(2.0*pi*i*j/real(base))-img*sin(2.0*pi*i*j/real(base))
-              end do
-           end do
-        end if
-     else
-        allocate(omega(0:nx-1,0:nx-1))
-        do j=0,nx-1
-           do i=0,nx-1
-              omega(i,j)=cos(2.0*pi*i*j/real(nx))-img*sin(2.0*pi*i*j/real(nx))
+     case ('i')
+        do j=0,1
+           do i=0,1
+              omega2(i,j)=iomega2(i,j)
            end do
         end do
-     end if
-
-     do j=0,nx-1
-        do i=0,nx-1
-           omegan(i,j)=cos(2.0*pi*i*j/real(nx))-img*sin(2.0*pi*i*j/real(nx))
-        end do
-     end do
-
-
-  case('i')
-     if(counter/=0)then
-        fact=exp(2.0*img*pi/real(nx))
-        fact=cos(2.0*pi/real(nx))+img*sin(2.0*pi/real(nx))
-        omega2=1.0
-        omega2(1,1)=-1.0
         do j=0,2
            do i=0,2
-              omega3(i,j)=cos(2.0*pi*i*j/3.0)+img*sin(2.0*pi*i*j/3.0)
+              omega3(i,j)=iomega3(i,j)
            end do
         end do
         do j=0,4
            do i=0,4
-              omega5(i,j)=cos(2.0*pi*i*j/5.0)+img*sin(2.0*pi*i*j/5.0)
+              omega5(i,j)=iomega5(i,j)
            end do
         end do
         do j=0,6
            do i=0,6
-              omega7(i,j)=cos(2.0*pi*i*j/7.0)+img*sin(2.0*pi*i*j/7.0)
+              omega7(i,j)=iomega7(i,j)
            end do
         end do
+     end select
+  end if
 
-        if(base/=1)then
-           allocate(omega(0:base-1,0:base-1))
-           do j=0,base-1
-              do i=0,base-1
-                 omega(i,j)=cos(2.0*pi*i*j/real(base))+img*sin(2.0*pi*i*j/real(base))
-              end do
-           end do
-        end if
-     end if
-
-     do j=0,nx-1
-        do i=0,nx-1
-           omegan(i,j)=cos(2.0*pi*i*j/real(nx))+img*sin(2.0*pi*i*j/real(nx))
+  if(present(omegan_fix))then
+     allocate(omega(0:base-1,0:base-1))
+     do j=0,base-1
+        do i=0,base-1
+           omega(i,j)=omega_fix(i,j)
         end do
      end do
-
-  case default
-     write(*,*) "******** ERROR : csign is bad. **********"
-     write(*,*) "Stop!"
-     stop
-  end select
+     do j=0,nx-1
+        do i=0,nx-1
+           omegan(i,j)=omegan_fix(i,j)
+        end do
+     end do
+  else
+     allocate(omega(0:base-1,0:base-1))
+     call rotate_calc( nx, csign, (/prim_num(1), prim_num(2), prim_num(3),  &
+  &                    prim_num(4), base/), omega, omegan )
+  end if
 
 !-- FFT 
 
@@ -248,10 +241,12 @@ end subroutine
 
 !-----------------------------------------------
 
-subroutine ffttp_2d( nx, ny, a, b, csign, prim )
+subroutine ffttp_2d( nx, ny, a, b, csign, prim, prim_fact, omega_fix,  &
+  &                  omegan_fix )
 !  Temperton's FFT (2d ver)
 !
 !  2d  fft  csign Ȥ, Ѵ, Ѵ롼
+  use Math_Const
   implicit none
   integer, intent(in) :: nx  ! ǿ 1
   integer, intent(in) :: ny  ! ǿ 2
@@ -261,12 +256,32 @@ subroutine ffttp_2d( nx, ny, a, b, csign, prim )
   character(1), optional, intent(in) :: prim  ! ǰʬ򤹤뤫ɤ
   ! [o=ʬ򤹤, x=ʬ򤷤ʤ] default=ʬ򤷤ʤ. ξ, ̾ DFT.
   ! ǰʬ򤹤, nx=2^a*3^b*5^c*7^d ޤǤʬ򤷤ʤ褦ˤ.
+  ! , 'x' ΤȤǤ, prim_fact ꤵƤ, Τ٤ FFT .
+  integer, dimension(5), optional :: prim_fact  ! prim = x ΤȤꤹ
+  ! Τ٤ FFT Ԥ. prim_fact=(/a,b,c,d/) : 2^a*3^b*5^c*7^d
+  ! , prim_fact ꤹ٤ nx Τ٤Ǥ뤳Ȥ.
+  complex, dimension(0:nx-1,0:nx-1), intent(in), optional :: omega_fix  ! ;ǰбž
+  complex, dimension(0:nx-1,0:nx-1), intent(in), optional :: omegan_fix  ! ž
   integer :: i
 
   if(present(prim))then
-     do i=0,ny-1
-        call ffttp_1d( nx, a(0:nx-1,i), b(0:nx-1,i), csign, prim )
-     end do
+     if(present(prim_fact))then
+        if(present(omegan_fix))then
+           do i=0,ny-1
+              call ffttp_1d( nx, a(0:nx-1,i), b(0:nx-1,i), csign, prim,  &
+  &                          prim_fact, omega_fix(0:nx-1,0:nx-1),  &
+  &                          omegan_fix(0:nx-1,0:nx-1) )
+           end do
+        else
+           do i=0,ny-1
+              call ffttp_1d( nx, a(0:nx-1,i), b(0:nx-1,i), csign, prim, prim_fact )
+           end do
+        end if
+     else
+        do i=0,ny-1
+           call ffttp_1d( nx, a(0:nx-1,i), b(0:nx-1,i), csign, prim )
+        end do
+     end if
   else
      do i=0,ny-1
         call ffttp_1d( nx, a(0:nx-1,i), b(0:nx-1,i), csign )
@@ -277,10 +292,11 @@ end subroutine
 
 !-----------------------------------------------
 
-subroutine r2c_ffttp_1d( nx, a, b, prim )
+subroutine r2c_ffttp_1d( nx, a, b, prim, prim_fact, omega_fix, omegan_fix )
 ! 1  FFT ׻롼
 !
 ! ϼ¿ǹԤ, ʣǿ֤.
+  use Math_Const
   implicit none
   integer, intent(in) :: nx  ! 1 ǡǿ
   real, intent(in), dimension(0:nx-1) :: a  ! ϼ¿ǡ
@@ -293,10 +309,15 @@ subroutine r2c_ffttp_1d( nx, a, b, prim )
   ! ޤ, inout °ΰ, ǡȾʬˤʤäƤ뤳Ȥ.
   ! ͤȤ, nx/2 ܤμ¿ǡ, n=0 ܤε˳Ǽ
   ! Ϥ뤳Ȥ.
+  ! , 'x' ΤȤǤ, prim_fact ꤵƤ, Τ٤ FFT .
+  integer, dimension(5), intent(in), optional :: prim_fact  ! prim = x ΤȤꤹ
+  ! Τ٤ FFT Ԥ. prim_fact=(/a,b,c,d/) : 2^a*3^b*5^c*7^d
+  ! Ϥ٤ nx Τ٤Ǥ.
+  complex, dimension(0:nx/2-1,0:nx/2-1), intent(in), optional :: omega_fix  ! ;ǰбž
+  complex, dimension(0:nx/2-1,0:nx/2-1), intent(in), optional :: omegan_fix  ! ž
   complex, dimension(0:nx/2-1) :: c, d
-  complex, parameter :: img=(0.0,1.0)
-  real, parameter :: pi=3.14159265
-  integer :: i, j, k
+  integer :: i
+  integer, dimension(5) :: prim_num
 
   if(mod(nx,2)/=0)then
      write(*,*) "*** ERROR ***"
@@ -312,7 +333,20 @@ subroutine r2c_ffttp_1d( nx, a, b, prim )
 !-- FFT 
 
   if(present(prim))then
-     call ffttp_1d( nx/2, c, d, 'r', prim )
+     if(present(prim_fact))then
+        prim_num=prim_fact
+        prim_num(1)=prim_num(1)-1  ! ǡǿȾʬˤʤäƤ뤿,
+                                   ! 2 Τ٤ 1 ĸäƤ.
+        if(present(omegan_fix))then
+           call ffttp_1d( nx/2, c, d, 'r', prim, prim_num,  &
+  &                       omega_fix(0:nx/2-1,0:nx/2-1),  &
+  &                       omegan_fix(0:nx/2-1,0:nx/2-1) )
+        else
+           call ffttp_1d( nx/2, c, d, 'r', prim, prim_num )
+        end if
+     else
+        call ffttp_1d( nx/2, c, d, 'r', prim )
+     end if
   else
      call ffttp_1d( nx/2, c, d, 'r' )
   end if
@@ -334,10 +368,11 @@ end subroutine
 
 !-----------------------------------------------
 
-subroutine c2r_ffttp_1d( nx, a, b, prim )
+subroutine c2r_ffttp_1d( nx, a, b, prim, prim_fact, omega_fix, omegan_fix )
 ! 1  FFT Ѵ׻롼
 !
 ! ʣǿǹԤ,¿֤.
+  use Math_Const
   implicit none
   integer, intent(in) :: nx  ! 1 ǡǿ
   complex, intent(in), dimension(0:nx/2-1) :: a  ! ʣǿǡ
@@ -350,10 +385,14 @@ subroutine c2r_ffttp_1d( nx, a, b, prim )
   ! ޤ, in °ΰ, ǡȾʬˤʤäƤ뤳Ȥ.
   ! ͤȤ, ϰ n=0  nx/2 ܤμ¿ǡäƤ褦
   ! ǡϤ.
+  ! , 'x' ΤȤǤ, prim_fact ꤵƤ, Τ٤ FFT .
+  integer, intent(in), optional, dimension(5) :: prim_fact  ! prim = x ΤȤꤹ
+  ! Τ٤ FFT Ԥ. prim_fact=(/a,b,c,d/) : 2^a*3^b*5^c*7^d
+  complex, dimension(0:nx/2-1,0:nx/2-1), intent(in), optional :: omega_fix  ! ;ǰбž
+  complex, dimension(0:nx/2-1,0:nx/2-1), intent(in), optional :: omegan_fix  ! ž
   complex, dimension(0:nx/2-1) :: c, d
-  complex, parameter :: img=(0.0,1.0)
-  real, parameter :: pi=3.14159265
-  integer :: i, j, k
+  integer :: i
+  integer, dimension(5) :: prim_num
 
   if(mod(nx,2)/=0)then
      write(*,*) "*** ERROR ***"
@@ -372,7 +411,20 @@ subroutine c2r_ffttp_1d( nx, a, b, prim )
 !-- FFT 
 
   if(present(prim))then
-     call ffttp_1d( nx/2, c, d, 'i', prim )
+     if(present(prim_fact))then
+        prim_num=prim_fact
+        prim_num(1)=prim_num(1)-1    ! ǡǿȾʬˤʤäƤ뤿,
+                                     ! 2 Τ٤ 1 ĸäƤ.
+        if(present(omegan_fix))then
+           call ffttp_1d( nx/2, c, d, 'i', prim, prim_num,  &
+  &                       omega_fix(0:nx/2-1,0:nx/2-1),  &
+  &                       omegan_fix(0:nx/2-1,0:nx/2-1) )
+        else
+           call ffttp_1d( nx/2, c, d, 'i', prim, prim_num )
+        end if
+     else
+        call ffttp_1d( nx/2, c, d, 'i', prim )
+     end if
   else
      call ffttp_1d( nx/2, c, d, 'i' )
   end if
@@ -387,4 +439,111 @@ end subroutine
 
 !-----------------------------------------------
 
+subroutine rotate_calc( nx, csign, prim_fact, omega, omegan )
+!  FFT ˻Ѥž׻.
+  use Math_Const
+  implicit none
+  integer, intent(in) :: nx  ! ǿ
+  character(1), intent(in) :: csign  ! ѴȽ [r=Ѵ, i=Ѵ]
+  integer, dimension(5) :: prim_fact  ! prim = x ΤȤꤹ
+  ! Τ٤ FFT Ԥ. prim_fact=(/a,b,c,d,e/) : 2^a*3^b*5^c*7^d*e
+  complex, dimension(0:prim_fact(5)-1,0:prim_fact(5)-1), intent(inout) :: omega
+  ! ;бž
+  complex, dimension(0:nx-1,0:nx-1), intent(inout) :: omegan ! ž
+  integer :: counter, base
+  integer :: i, j  ! do loop 
+
+  base=prim_fact(5)
+
+  counter=0
+  do i=1,4
+     counter=counter+prim_fact(i)
+  end do
+
+!-- ž
+
+  select case(csign)
+  case('r')
+     if(counter/=0)then
+        if(base/=1)then
+           do j=0,base-1
+              do i=0,base-1
+                 omega(i,j)=cos(2.0*pi*i*j/real(base))-img*sin(2.0*pi*i*j/real(base))
+              end do
+           end do
+        end if
+        do j=0,nx-1
+           do i=0,nx-1
+              omegan(i,j)=cos(2.0*pi*i*j/real(nx))-img*sin(2.0*pi*i*j/real(nx))
+           end do
+        end do
+
+     else
+        do j=0,nx-1
+           do i=0,nx-1
+              omega(i,j)=cos(2.0*pi*i*j/real(nx))-img*sin(2.0*pi*i*j/real(nx))
+              omegan(i,j)=omega(i,j)
+           end do
+        end do
+     end if
+
+
+  case('i')
+     if(counter/=0)then
+        if(base/=1)then
+           do j=0,base-1
+              do i=0,base-1
+                 omega(i,j)=cos(2.0*pi*i*j/real(base))+img*sin(2.0*pi*i*j/real(base))
+              end do
+           end do
+        end if
+        do j=0,nx-1
+           do i=0,nx-1
+              omegan(i,j)=cos(2.0*pi*i*j/real(nx))+img*sin(2.0*pi*i*j/real(nx))
+           end do
+        end do
+     else
+        do j=0,nx-1
+           do i=0,nx-1
+              omega(i,j)=cos(2.0*pi*i*j/real(nx))+img*sin(2.0*pi*i*j/real(nx))
+              omegan(i,j)=omega(i,j)
+           end do
+        end do
+     end if
+
+  case default
+     write(*,*) "******** ERROR : csign is bad. **********"
+     write(*,*) "Stop!"
+     stop
+  end select
+
+end subroutine
+
+!-----------------------------------------------
+
+subroutine prim_calc( n, factor, resid )
+  ! 2,3,5,7 ˤĤƤǰʬԤ.
+  implicit none
+  integer, intent(in) :: n  ! ʬ򤹤
+  integer, intent(inout), dimension(4) :: factor  ! ʬ򤷤Ȥγǰ
+  ! ΤȤ, factor(1:4)=(/a,b,c,d/) Ǥ, factor(5)=e Ȥ,
+  ! n=2^a*3^b*5^c*7^d*e ȤˤʤäƤ.
+  integer, intent(inout) :: resid  ! residual prim factor
+  integer :: i, base
+  integer, dimension(4) :: prim_dim
+
+  prim_dim=(/2,3,5,7/)
+  base=n
+  factor=(/0,0,0,0/)
+  do i=1,4
+     do while(mod(base,prim_dim(i))==0)
+        base=base/prim_dim(i)
+        factor(i)=factor(i)+1
+     end do
+  end do
+
+  resid=base
+
+end subroutine
+
 end module
