@@ -44,6 +44,8 @@ subroutine write_file( file_name, nx, ny, rec_num, var, mode )  ! Ͻϥ롼
   integer :: i, j  ! 
   character(10) :: cmode
 
+  cmode=''
+
   if(present(mode))then
      cmode=mode
   else
@@ -95,6 +97,10 @@ subroutine request_dim_grads( fname, dim_len )
   allocate(ctl_cval(nl))
   allocate(ctl_hval(10,nl))
 
+  ctl_cval=''
+  ctl_hval=''
+  tmpc=''
+
   call read_file_text( trim(fname), 1, nl, ctl_cval, forma='(a1000)' )
   call read_file_text( trim(fname), 2, nl-1, ctl_hval(1:2,1:nl-1) )
 
@@ -126,17 +132,19 @@ end subroutine
 
 subroutine request_axis_grads( fname, axis_name, x )
 ! GrADS Υȥե뤫 1 μǡ.
-! , linear פΤб.
+! , linear, levels פΤб.
   implicit none
   character(*), intent(in) :: fname  ! GrADS Υȥե
   character(*), intent(in) :: axis_name  ! ɤ߽Ф̾.
                               ! xdef, ydef, zdef  3 ѥ
   real, intent(inout) :: x(:)  ! κɸ
-  character(1000), allocatable, dimension(:) :: ctl_cval, ctl_vval
+  character(1000), allocatable, dimension(:) :: ctl_cval
+  character(100), allocatable, dimension(:) :: ctl_vval
   character(100), allocatable, dimension(:,:) :: ctl_hval
-  integer :: nl, i, nx
+  integer :: nl, i, j, nx
   real :: vmin, dv
   character(1000) :: tmpc
+  character(100), allocatable, dimension(:) :: dummy
 
   nl=line_number_counter( trim(fname) )
   nx=size(x)
@@ -144,6 +152,13 @@ subroutine request_axis_grads( fname, axis_name, x )
   allocate(ctl_cval(nl))
   allocate(ctl_hval(2,nl))
   allocate(ctl_vval(5))
+  allocate(dummy(nx+3))
+
+  ctl_cval=''
+  ctl_vval=''
+  ctl_hval=''
+  tmpc=''
+  dummy=''
 
   call read_file_text( trim(fname), 1, nl, ctl_cval, forma='(a1000)' )
   call read_file_text( trim(fname), 2, nl-1, ctl_hval(1:2,1:nl-1) )
@@ -151,15 +166,23 @@ subroutine request_axis_grads( fname, axis_name, x )
   do i=1,nl
      tmpc=trim(adjustl(ctl_cval(i)))
      if(tmpc(1:4)==trim(axis_name))then
-        call read_file_text( trim(fname), 5, 1, ctl_hval(1:2,1:nl-1), skip=i-1 )
+        call read_file_text( trim(fname), 5, 1, ctl_vval(1:5), skip=i-1 )
         if(trim(ctl_vval(3))=='linear')then
            read(ctl_vval(4),*) vmin
            read(ctl_vval(5),*) dv
            x=(/((vmin+dv*(i-1)),i=1,nx)/)
         else
-           write(*,*) "ERROR : This routine not support option 'levels'"
-           write(*,*) "STOP."
-           stop
+           if(trim(ctl_vval(3))=='levels')then
+              call read_file_text( trim(fname), nx+3, 1, dummy, skip=i-1 )
+              do j=4,nx+3
+                 read(dummy(j),*) x(j-3)
+              end do
+           else
+              write(*,*) "ERROR (request_axis_grads) : ", trim(ctl_vval(3))
+              write(*,*) "Mode is neither 'levels' nor 'linear'."
+              write(*,*) "STOP."
+              stop
+           end if
         end if
      end if
   end do
@@ -187,6 +210,11 @@ subroutine request_vardim_grads( fname, var_name, nz )
   allocate(ctl_hval(2,nl))
   allocate(ctl_vval(5))
 
+  ctl_vval=''
+  ctl_hval=''
+  ctl_cval=''
+  tmpc=''
+
   call read_file_text( trim(fname), 1, nl, ctl_cval, forma='(a1000)' )
   call read_file_text( trim(fname), 2, nl-1, ctl_hval(1:2,1:nl-1) )
 
@@ -222,11 +250,12 @@ subroutine read_file_grads( fname, val_name, dim_len, intvz, intvt, val )
   &  :: val  ! ɤ߽ФͤǼѿ.
   character(1000), allocatable, dimension(:) :: ctl_cval
   character(100), allocatable, dimension(:,:) :: ctl_hval
-  integer :: nl, nx, ny, nz, nt
+  integer :: nl, nx, ny, nz, nt, mon_num
   integer :: i, j
   character(1000) :: tmpc, ctmp, header, footer, iname
   integer, dimension(10) :: cont_flag
   integer :: t_fact, year, month, day, hour, counter_start, read_flag, counter
+  integer :: year_r, month_r, day_r, hour_r
   logical, dimension(4) :: t_fact_flag, date_flag
 
   nl=line_number_counter( trim(fname) )
@@ -238,6 +267,14 @@ subroutine read_file_grads( fname, val_name, dim_len, intvz, intvt, val )
   allocate(ctl_cval(nl))
   allocate(ctl_hval(10,nl))
 
+  ctl_cval=''
+  ctl_hval=''
+  tmpc=''
+  ctmp=''
+  header=''
+  footer=''
+  iname=''
+
 !-- ctl file reading
 
   call read_file_text( trim(fname), 1, nl, ctl_cval, forma='(a1000)' )
@@ -274,14 +311,20 @@ subroutine read_file_grads( fname, val_name, dim_len, intvz, intvt, val )
 !-- reading array estimate
 
   read_flag=0
-  do i=cont_flag(1),cont_flag(3)-1
+  do i=cont_flag(1)+1,cont_flag(3)-1
      read(ctl_hval(2,i),*) counter
-     read_flag=read_flag+counter
+     if(counter==0)then
+        read_flag=read_flag+1
+     else
+        read_flag=read_flag+counter
+     end if
   end do
 
 !-- t_fact caluculate
 
   t_fact_flag(1:4)=.false.
+  call read_file_text( trim(fname), 5, 1, ctl_hval(1:5,cont_flag(5)),  &
+  &                    skip=cont_flag(5)-1 )
   tmpc=trim(ctl_hval(5,cont_flag(5)))
   select case (tmpc(len_trim(adjustl(tmpc))-1:len_trim(adjustl(tmpc))))
   case ('yr')
@@ -315,25 +358,21 @@ subroutine read_file_grads( fname, val_name, dim_len, intvz, intvt, val )
            date_flag(1)=.true.
            if(t_fact_flag(1).eqv..true.)then
               footer=tmpc(i+3:len_trim(adjustl(ctl_hval(2,cont_flag(4)))))
-              exit
            end if
         case ('m2')
            date_flag(2)=.true.
            if(t_fact_flag(1).eqv..true.)then
               footer=tmpc(i+3:len_trim(adjustl(ctl_hval(2,cont_flag(4)))))
-              exit
            end if
         case ('d2')
            date_flag(3)=.true.
            if(t_fact_flag(1).eqv..true.)then
               footer=tmpc(i+3:len_trim(adjustl(ctl_hval(2,cont_flag(4)))))
-              exit
            end if
         case ('h2')
            date_flag(4)=.true.
            if(t_fact_flag(1).eqv..true.)then
               footer=tmpc(i+3:len_trim(adjustl(ctl_hval(2,cont_flag(4)))))
-              exit
            end if
         end select
      end if
@@ -344,14 +383,22 @@ subroutine read_file_grads( fname, val_name, dim_len, intvz, intvt, val )
      header=trim(tmpc(2:len_trim(adjustl(ctl_hval(2,cont_flag(4))))))
      footer=''
   end if
-
 !-- initial time reading
 
   tmpc=trim(ctl_hval(4,cont_flag(5)))
   read(tmpc(1:2),*) hour
-  read(tmpc(4:5),*) day
-  read(tmpc(9:12),*) year
-  select case (tmpc(6:8))
+  select case (tmpc(3:3))
+  case (':')
+     read(tmpc(7:8),*) day
+     read(tmpc(12:15),*) year
+     mon_num=9  ! ɽʸϤޤ
+  case ('Z')
+     read(tmpc(4:5),*) day
+     read(tmpc(9:12),*) year
+     mon_num=6  ! ɽʸϤޤ
+  end select
+
+  select case (tmpc(mon_num:mon_num+2))
   case('Jan')
      month=1
   case('Feb')
@@ -378,6 +425,11 @@ subroutine read_file_grads( fname, val_name, dim_len, intvz, intvt, val )
      month=12
   end select
 
+  year_r=year
+  month_r=month
+  day_r=day
+  hour_r=hour
+
 !-- reading data
 
   do i=intvt(1),intvt(2)
@@ -389,19 +441,19 @@ subroutine read_file_grads( fname, val_name, dim_len, intvz, intvt, val )
         select case (j)
         case (1)
            if(t_fact_flag(1).eqv..true.)then
-              year=year+t_fact*(i-1)
+              year=year_r+t_fact*(i-1)
            end if
         case (2)
            if(t_fact_flag(2).eqv..true.)then
-              month=month+t_fact*(i-1)
+              month=month_r+t_fact*(i-1)
            end if
         case (3)
            if(t_fact_flag(3).eqv..true.)then
-              day=day+t_fact*(i-1)
+              day=day_r+t_fact*(i-1)
            end if
         case (4)
            if(t_fact_flag(4).eqv..true.)then
-              hour=hour+t_fact*(i-1)
+              hour=hour_r+t_fact*(i-1)
            end if
         end select
 
@@ -509,19 +561,22 @@ subroutine read_file_grads( fname, val_name, dim_len, intvz, intvt, val )
         end do
      end do
 
-     do j=4,1,-1
+     do j=1,4
         if(date_flag(j).eqv..true.)then
            select case (j)
            case (1)
               write(ctmp,'(i4.4)') year
+              iname=trim(iname)//trim(adjustl(ctmp))
            case (2)
               write(ctmp,'(i2.2)') month
+              iname=trim(iname)//trim(adjustl(ctmp))
            case (3)
               write(ctmp,'(i2.2)') day
+              iname=trim(iname)//trim(adjustl(ctmp))
            case (4)
               write(ctmp,'(i2.2)') hour
+              iname=trim(iname)//trim(adjustl(ctmp))
            end select
-           iname=trim(iname)//trim(adjustl(ctmp))
         end if
      end do
 
@@ -531,7 +586,7 @@ subroutine read_file_grads( fname, val_name, dim_len, intvz, intvt, val )
         call read_file( trim(iname), nx, ny, read_flag+j,  &
   &                     val(:,:,j,i) )
      end do
-     write(*,*) "finishing to read file", trim(iname), nx, ny, read_flag+j, i
+     write(*,*) "finishing to read file", trim(iname), nx, ny, read_flag+intvz(1), read_flag+intvz(2), i
   end do
 
 end subroutine
