@@ -144,18 +144,27 @@ end subroutine invert_mat
 !  ʲ, ϢΩ 1 ε롼
 !-----------------------------------------------------------------
 
-subroutine gausss( a, b, x )
+subroutine gausss( c, d, x )
 ! ʬԥܥåդξõˡ
   implicit none
-  real, intent(inout) :: b(:)
-  real, intent(inout) :: a(size(b),size(b))  !  ( 1 ǤԤɽ)
-  real, intent(inout) :: x(size(b))
+  real, intent(in) :: d(:)
+  real, intent(in) :: c(size(d),size(d))  !  ( 1 ǤԤɽ)
+  real, intent(inout) :: x(size(d))
+  real :: b(size(d))
+  real :: a(size(d),size(d))  !  ( 1 ǤԤɽ)
   real :: s, pivotb
-  real :: pivot(size(b)+1)
+  real :: pivot(size(d)+1)
   integer :: piv, i, j, k, nmax
 
   nmax=size(b)
 
+  do k=1,nmax
+     do j=1,nmax
+        a(j,k)=c(j,k)
+     end do
+     b(k)=d(k)
+  end do
+
 !-- ʾõ ---
 !-- A(I,J) ʾõ ---
   do k=1,nmax-1
@@ -221,7 +230,7 @@ subroutine LU_devs( a, b, x, itermax )
   integer :: ip(size(b))
   real :: scale(size(b)), dx(size(b))
   real :: s, t, pivot, xnorm, dxnorm
-  real :: s1, s2, s3, s4, s5, t0, t1, t2, t3, t4, eps
+  real :: s1, s2, s3, s4, s5, t0, t1, t3, t4, eps
   integer :: iter, nmax
   integer :: p, itemp, i, j, k
 
@@ -377,7 +386,7 @@ subroutine Gau_Sei(a, b, eps, x)
   real, intent(inout) :: a(size(b),size(b))  !  ( 1 Ǥιʬɽ)
   real, intent(in) :: eps  ! «
   real, intent(inout) :: x(size(b))  ! 򤯲
-  integer :: i, j, k, l, m, n  ! ƥ졼ź
+  integer :: i, j  ! ƥ졼ź
   real :: xn  !  x(i) Υƥΰ
   real :: err, err_max  ! 
   integer :: nx
@@ -448,7 +457,7 @@ subroutine Jacobi_algebra(a, b, eps, x)
   real, intent(in) :: eps  ! «
   real, intent(inout) :: x(size(b))  ! 򤯲
   real :: y(size(b))  ! 䥳ˡǻѤǼ, ǰƹ.(xn )
-  integer :: i, j, k, l, m, n  ! ƥ졼ź
+  integer :: i, j  ! ƥ졼ź
   real :: err, err_max  ! 
   integer :: nx
 
@@ -524,7 +533,7 @@ subroutine SOR_Gau_Sei(a, b, eps, accel, x)
   real, intent(in) :: accel  ! ®. , Ū accel >= 2 ǤȯΤ,
                              ! Ͱʾ夬ꤵȥ顼ǻߤ.
   real, intent(inout) :: x(size(b))  ! 򤯲
-  integer :: i, j, k, l, m, n  ! ƥ졼ź
+  integer :: i, j  ! ƥ졼ź
   real :: xn  !  x(i) Υƥΰ
   real :: err, err_max  ! 
   integer :: nx
@@ -608,7 +617,7 @@ subroutine SOR_Jacobi_algebra(a, b, eps, accel, x)
                              ! Ͱʾ夬ꤵȥ顼ǻߤ.
   real, intent(inout) :: x(size(b))  ! 򤯲
   real :: y(size(b))  ! 䥳ˡǻѤǼ, ǰƹ.(xn )
-  integer :: i, j, k, l, m, n  ! ƥ졼ź
+  integer :: i, j  ! ƥ졼ź
   real :: err, err_max  ! 
   integer :: nx
 
@@ -692,9 +701,9 @@ subroutine eigenvalue_power( a, eps, eigenval, eigenvec )
   real, intent(in) :: a(size(eigenvec),size(eigenvec))  ! ͭͤ ( 1 ǤԤɽ)
   real, intent(in) :: eps  ! «Ƚ
   real, intent(inout) :: eigenval  !  a κͭ
-  integer :: i, j, k
+  integer :: i, j
   real, dimension(size(eigenvec)) :: x, y
-  real :: tmp1, tmp2, err_max, err
+  real :: tmp1, tmp2, err_max
   integer :: nx
 
   nx=size(eigenvec)
@@ -856,8 +865,8 @@ subroutine QR_dev( a, lambda, eps, method )
                 ! ǥեȤоι.
                 ! 'S' : оι -> гѲԤ,
                 ! 'A' : оι -> Householder ѴԤ.
-  integer :: i, j, k, l, m, n
-  real, dimension(size(a,1),size(a,2)) :: Q, R, tmp_a, new_a
+  integer :: i, j, n
+  real, dimension(size(a,1),size(a,2)) :: tmp_a, new_a
 
   n=size(a,1)
 
@@ -891,28 +900,6 @@ end subroutine QR_dev
 !-----------------------------------------
 !-----------------------------------------
 
-!-- ʲ, ȯ !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-subroutine eigen_power_all( a, lambda, eigen_vec, eps )
-!  ٤ˡѤ, a ˤĤƤƤθͭͤȤȼͭ٥ȥ
-!  ׻롼.
-  implicit none
-  real, intent(in) :: a(:,:)  ! ͭͤ [ 1 Ǥ]
-  real, intent(inout) :: lambda(size(a,1))  ! a θͭ
-  real, intent(inout) :: eigen_vec(size(a,1),size(a,2))  ! lambda(i) бͭ٥ȥ, Ǥͭ lambda(i) бƤ.
-  real, intent(in), optional :: eps  ! ȿˡμ«
-  integer :: i, j, k, l, m, n
-  real, dimension(size(a,1),size(a,2)) :: tmp_a, new_a
-
-  n=size(a,1)
-
-
-
-
-end subroutine
-
-!-----------------------------------------
-!-----------------------------------------
-
 subroutine schumit_norm( u, v )
 ! ߥåȤľˡѤ, nx ٥ȥľ򲽤.
 !  1 Ǥ٥ȥγʬ,  2 ʬ٥ȥ뷲 1 ٥ȥɽ.
@@ -922,7 +909,6 @@ subroutine schumit_norm( u, v )
   real, intent(in) :: u(:,:)  ! ľ򲽤Υ٥ȥ
   real, intent(inout) :: v(size(u,1),size(u,2))  ! ľ򲽸Υ٥ȥ
   integer :: i, j, k, nx, ny
-  real :: tmp
   real :: tmpn(size(u,2))  ! ԤȤ, ΥͤǼ.
   real :: tmps(size(u,1))  ! ±黻κݤΰǼ˻.
 
@@ -956,6 +942,27 @@ subroutine schumit_norm( u, v )
 
 end subroutine schumit_norm
 
+!-----------------------------------------
+!-----------------------------------------
+
+!-- ʲ, ȯ !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+subroutine eigen_power_all( a, lambda, eigen_vec, eps )
+!  ٤ˡѤ, a ˤĤƤƤθͭͤȤȼͭ٥ȥ
+!  ׻롼.
+  implicit none
+  real, intent(in) :: a(:,:)  ! ͭͤ [ 1 Ǥ]
+  real, intent(inout) :: lambda(size(a,1))  ! a θͭ
+  real, intent(inout) :: eigen_vec(size(a,1),size(a,2))  ! lambda(i) бͭ٥ȥ, Ǥͭ lambda(i) бƤ.
+  real, intent(in), optional :: eps  ! ȿˡμ«
+  integer :: n
+
+  n=size(a,1)
+
+
+
+
+end subroutine
+
 !-----------------------------------------
 ! ʲ, private °դ롼
 !-----------------------------------------
@@ -1024,7 +1031,7 @@ real function vec_dot( u, v )
   implicit none
   real, intent(in) :: u(:)
   real, intent(in) :: v(size(u))
-  integer :: i, j, nx
+  integer :: i, nx
   real :: tmp
 
   nx=size(u)
