@@ -583,7 +583,7 @@ subroutine AS_LEGENDRE_f(n, m, x, p)
   integer, intent(in) :: m  ! vZ legendre ֐̐
   real, intent(in) :: x(:)  ! 
   real, intent(inout) :: p(abs(m):n,size(x))  ! vZ legendre ֐
-  integer :: i, j, k, abm
+  integer :: i, j, abm
   integer :: nmax  ! z x ̗vf
   real :: coe
 
@@ -677,7 +677,7 @@ subroutine AS_LEGENDRE_d(n, m, x, p)
   integer, intent(in) :: m  ! vZ legendre ֐̐
   double precision, intent(in) :: x(:)  ! 
   double precision, intent(inout) :: p(abs(m):n,size(x))  ! vZ legendre ֐
-  integer :: i, j, k, abm
+  integer :: i, j, abm
   integer :: nmax  ! z x ̗vf
   double precision :: coe
 
@@ -890,8 +890,8 @@ subroutine gauss_lat( n, lat, eps )
                                 ! ftHg 1.0e-6.
   real :: tmp(0:n,1)
   real :: nu(1)
-  integer :: i, j, k
-  real :: err_max, diff, eps_max
+  integer :: k
+  real :: diff, eps_max
 
   if(present(eps))then
      eps_max=eps
